
#ifndef _C15_ev704_
#define _C15_ev704_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F776_11945(EIF_REFERENCE);
extern void EIF_Minit704(void);
extern void F3002_33755(EIF_REFERENCE);
extern long O11616[];

#ifdef __cplusplus
}
#endif

#endif
